pitcharraytools.PitchArrayCell
==============================

.. abjad-lineage:: abjad.tools.pitcharraytools.PitchArrayCell.PitchArrayCell

.. autoclass:: abjad.tools.pitcharraytools.PitchArrayCell.PitchArrayCell

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.pitcharraytools.PitchArrayCell.PitchArrayCell.column_indices
      ~abjad.tools.pitcharraytools.PitchArrayCell.PitchArrayCell.indices
      ~abjad.tools.pitcharraytools.PitchArrayCell.PitchArrayCell.is_first_in_row
      ~abjad.tools.pitcharraytools.PitchArrayCell.PitchArrayCell.is_last_in_row
      ~abjad.tools.pitcharraytools.PitchArrayCell.PitchArrayCell.matches_cell
      ~abjad.tools.pitcharraytools.PitchArrayCell.PitchArrayCell.next
      ~abjad.tools.pitcharraytools.PitchArrayCell.PitchArrayCell.parent_array
      ~abjad.tools.pitcharraytools.PitchArrayCell.PitchArrayCell.parent_column
      ~abjad.tools.pitcharraytools.PitchArrayCell.PitchArrayCell.parent_row
      ~abjad.tools.pitcharraytools.PitchArrayCell.PitchArrayCell.pitches
      ~abjad.tools.pitcharraytools.PitchArrayCell.PitchArrayCell.previous
      ~abjad.tools.pitcharraytools.PitchArrayCell.PitchArrayCell.row_index
      ~abjad.tools.pitcharraytools.PitchArrayCell.PitchArrayCell.token
      ~abjad.tools.pitcharraytools.PitchArrayCell.PitchArrayCell.weight
      ~abjad.tools.pitcharraytools.PitchArrayCell.PitchArrayCell.width
      ~abjad.tools.pitcharraytools.PitchArrayCell.PitchArrayCell.__eq__
      ~abjad.tools.pitcharraytools.PitchArrayCell.PitchArrayCell.__format__
      ~abjad.tools.pitcharraytools.PitchArrayCell.PitchArrayCell.__ne__
      ~abjad.tools.pitcharraytools.PitchArrayCell.PitchArrayCell.__repr__
      ~abjad.tools.pitcharraytools.PitchArrayCell.PitchArrayCell.__str__

Bases
-----

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.pitcharraytools.PitchArrayCell.PitchArrayCell.column_indices
   :noindex:

.. autoattribute:: abjad.tools.pitcharraytools.PitchArrayCell.PitchArrayCell.indices
   :noindex:

.. autoattribute:: abjad.tools.pitcharraytools.PitchArrayCell.PitchArrayCell.is_first_in_row
   :noindex:

.. autoattribute:: abjad.tools.pitcharraytools.PitchArrayCell.PitchArrayCell.is_last_in_row
   :noindex:

.. autoattribute:: abjad.tools.pitcharraytools.PitchArrayCell.PitchArrayCell.next
   :noindex:

.. autoattribute:: abjad.tools.pitcharraytools.PitchArrayCell.PitchArrayCell.parent_array
   :noindex:

.. autoattribute:: abjad.tools.pitcharraytools.PitchArrayCell.PitchArrayCell.parent_column
   :noindex:

.. autoattribute:: abjad.tools.pitcharraytools.PitchArrayCell.PitchArrayCell.parent_row
   :noindex:

.. autoattribute:: abjad.tools.pitcharraytools.PitchArrayCell.PitchArrayCell.previous
   :noindex:

.. autoattribute:: abjad.tools.pitcharraytools.PitchArrayCell.PitchArrayCell.row_index
   :noindex:

.. autoattribute:: abjad.tools.pitcharraytools.PitchArrayCell.PitchArrayCell.token
   :noindex:

.. autoattribute:: abjad.tools.pitcharraytools.PitchArrayCell.PitchArrayCell.weight
   :noindex:

.. autoattribute:: abjad.tools.pitcharraytools.PitchArrayCell.PitchArrayCell.width
   :noindex:

Read/write properties
---------------------

.. autoattribute:: abjad.tools.pitcharraytools.PitchArrayCell.PitchArrayCell.pitches
   :noindex:

Methods
-------

.. automethod:: abjad.tools.pitcharraytools.PitchArrayCell.PitchArrayCell.matches_cell
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.pitcharraytools.PitchArrayCell.PitchArrayCell.__eq__
   :noindex:

.. automethod:: abjad.tools.pitcharraytools.PitchArrayCell.PitchArrayCell.__format__
   :noindex:

.. automethod:: abjad.tools.pitcharraytools.PitchArrayCell.PitchArrayCell.__ne__
   :noindex:

.. automethod:: abjad.tools.pitcharraytools.PitchArrayCell.PitchArrayCell.__repr__
   :noindex:

.. automethod:: abjad.tools.pitcharraytools.PitchArrayCell.PitchArrayCell.__str__
   :noindex:
